#!/usr/bin/env python3
import logging
from flask import Flask
from flask_mqtt import logger
from flask_restful import Api
import sentry_sdk
from sentry_sdk.integrations.flask import FlaskIntegration
from sentry_sdk.integrations.logging import LoggingIntegration

from resources import *
from config import *
from mqtt_flask_instance import mqtt

from mqtt_methods import handle_status_message

"""
Main Flask RESTful API
"""

__author__ = "@tormakris"
__copyright__ = "Copyright 2020, Birbnetes Team"
__module_name__ = "app"
__version__text__ = "1"

if SENTRY_DSN:
    sentry_logging = LoggingIntegration(
        level=logging.DEBUG,
        event_level=logging.ERROR
    )
    sentry_sdk.init(
        dsn=SENTRY_DSN,
        integrations=[FlaskIntegration(), sentry_logging],
        traces_sample_rate=1.0,
        send_default_pii=True,
        release=RELEASE_ID,
        environment=RELEASEMODE,
        _experiments={"auto_enabling_integrations": True}
    )

app = Flask(__name__)
app.config['MQTT_BROKER_URL'] = MQTT_HOSTNAME
MQTT_PORT = int(MQTT_PORT)
app.config['MQTT_BROKER_PORT'] = MQTT_PORT
app.config['MQTT_USERNAME'] = MQTT_USERNAME
app.config['MQTT_PASSWORD'] = MQTT_PASSWORD
app.config['MQTT_REFRESH_TIME'] = 1.0  # refresh time in seconds

api = Api(app)
ma.init_app(app)
mqtt.init_app(app)

@mqtt.on_log()
def handle_logging(client, userdata, level, buf):
    logger.log(level, buf)


@mqtt.on_connect()
def handle_connect(client, userdata, flags, rc):
    mqtt.subscribe(f"{MQTT_STATUS_TOPIC}/#")


@mqtt.on_topic(f"{config.MQTT_STATUS_TOPIC}/#")
def handle_status_message_proxy(*args, **kwargs):
    """
    This proxy puts the call into a Flask context, so database operations can be performed
    """
    with app.app_context():
        handle_status_message(*args, **kwargs)


api.add_resource(AllDevicesOfflineResource, "/devices/offline")
api.add_resource(AllDevicesOnlineResource, "/devices/online")
api.add_resource(DeviceOfflineResrouce, "/devices/{deviceid}/offline")
api.add_resource(DeviceOnlineResrouce, "/devices/{deviceid}/online")
api.add_resource(SensorOfflineResource, "/devices/{deviceid}/{sensorid}/offline")
api.add_resource(SensorOnlineResource, "/devices/{deviceid}/{sensorid}/online")
